from celery import Celery
import numpy as np

from context import cells
from context import entropy
from context import cech

broker = 'amqp://'
backend = 'amqp://'
celery = Celery('tasks', broker=broker, backend=backend)

@celery.task(bind=True)
def recursive_enumerate(self, vertices, epsilon, depth):
    """ Runs the recursive enumeration method
    """
    # create the index array
    index_array = np.empty([vertices.shape[0]])
    for i in range(vertices.shape[0]):
        index_array[i] = i

    centre_list, radius_list, basis_list = cells.recursive_enumerate(vertices,
        index_array, epsilon, depth)

    self.update_state(state='COMPLETED')

    return {
        'state': 'Completed',
        'results': {
            'centre_list': centre_list.tolist(),
            'radius_list': radius_list.tolist(),
            'basis_list': basis_list.tolist()
        }
    }

@celery.task(bind=True)
def simplical_complex_entropy(self, a, p):
    """ Runs the simplical complex entropy method
    """
    e, err, q = entropy.simplical_complex_entropy(a, p)

    return {
        'state': 'Completed',
        'results': {
            'e': e,
            'err': err,
            'q': q.tolist()
        }
    }

@celery.task(bind=True)
def cech_task(self, vertices, epsilon):
    """ Runs the cech complex method
    """
    centre_list, radius_list, basis_list = cech.calculate(vertices, epsilon)

    return {
        'state': 'Completed',
        'results': {
            'centre_list': centre_list.tolist(),
            'radius_list': radius_list.tolist(),
            'basis_list': basis_list.tolist()
        }
    }
